import * as React from "react";
import { StyledView } from "./styles/TextField";
class ContentEditable extends React.Component {
    constructor() {
        super(...arguments);
        this.state = { editing: false };
        this.selectAll = () => {
            let sel, range;
            if (window.getSelection && document.createRange) {
                range = document.createRange();
                range.selectNodeContents(this.elem);
                sel = window.getSelection();
                sel.removeAllRanges();
                sel.addRange(range);
            }
        };
        this.handleKeyDown = (evt) => {
            //exit edit mode on escape key
            if (evt.key === 'Escape') {
                evt.preventDefault();
                this.elem.blur();
            }
        };
        this.finishEditing = () => {
            const newValue = this.elem && this.elem.innerHTML;
            this.setState({ editing: false });
            this.props.onChange(newValue);
        };
        this.startEditing = () => {
            const { disabled, displayContent } = this.props;
            !disabled && this.setState({ editing: true }, () => displayContent && this.selectAll());
        };
        this.content = () => {
            const { content, displayContent } = this.props;
            return this.state.editing ? content : displayContent ? displayContent : content;
        };
    }
    shouldComponentUpdate(nextProps, nextState) {
        return (nextProps.content !== this.props.content ||
            nextProps.disabled !== this.props.disabled ||
            nextState.editing !== this.state.editing);
    }
    render() {
        const { disabled, onKeyPress } = this.props;
        return <StyledView suppressContentEditableWarning innerRef={elem => (this.elem = elem)} contentEditable={!disabled} placeholder='click to edit' dangerouslySetInnerHTML={{ __html: this.content() }} onClick={this.startEditing} onBlur={this.finishEditing} onKeyDown={this.handleKeyDown} onKeyPress={onKeyPress}/>;
    }
}
ContentEditable.defaultProps = {
    disabled: false,
    onKeyDown: () => { },
    onKeyPress: () => { }
};
export default ContentEditable;
//# sourceMappingURL=ContentEditable.jsx.map